/**
 * 
 */
package uk.org.wuglug.gryle.ui.m;

import java.io.File;
import java.io.Serializable;
import java.util.Collections;
import java.util.Comparator;

import javax.naming.Name;

/**
 * @author Richard Warburton
 * Data Class for one song
 */
public class SongModel implements Serializable {
	
	//  COMPARATORS ---------------------------------
	
	public static class TrackComparator implements Comparator<SongModel> {
		public int compare(SongModel o1, SongModel o2) {
			return new Integer(o1.getTrack()).compareTo(o2.getTrack());
		}
	}
	
	public static class ArtistComparator implements Comparator<SongModel> {
		public int compare(SongModel o1, SongModel o2) {
			return o1.getArtist().compareTo(o2.getArtist());
		}
	}
	
	public static class NameComparator implements Comparator<SongModel> {
		public int compare(SongModel o1, SongModel o2) {
			return o1.getName().compareTo(o2.getName());
		}
	}
	
	public static class AlbumComparator implements Comparator<SongModel> {
		public int compare(SongModel o1, SongModel o2) {
			return o1.getAlbum().compareTo(o2.getAlbum());
		}
	}
	
	public static class TimeComparator implements Comparator<SongModel> {
		public int compare(SongModel o1, SongModel o2) {
			return new Float(o1.getTime()).compareTo(o2.getTime());
		}
	}
	
	// COLUMN NAMES FOR SONGS -------------------------------
	
	public final static String[] Columns = {
		"Track",
		"Artist",
		"Name",
		"Album",
		"Time"
	};
	
	public final static Comparator[] comparators = {
		new TrackComparator(),
		new ArtistComparator(),
		new NameComparator(),
		new AlbumComparator(),
		new TimeComparator()
	};
	
	public static int[] indices = {
		0,
		1,
		2,
		3,
		4
	};
	
	//  MAIN CLASS BODY ---------------------------------
	
	private int track;
	private String artist;
	private String name;
	private String album;
	private float time;
	private File location;
	
	
	
	/**
	 * @return the location
	 */
	public File getLocation() {
		return location;
	}

	/**
	 * @param track
	 * @param artist
	 * @param name
	 * @param album
	 * @param time
	 */
	public SongModel(File location) {
		super();
		
		this.track = 0;
		this.artist = location.getParent();
		this.name = location.getName();
		this.album = location.getAbsolutePath();
		this.time = 2;
		this.location = location;
	}
	
	public Object getVal(int index) {
		switch(index) {
		case 0: return this.track;
		case 1: return this.artist;
		case 2: return this.name;
		case 3: return this.album;
		case 4: return this.time;
		default: return null;
		}
	}
	
	/**
	 * Method used in filtering the list
	 * @param input
	 * @return
	 */
	public boolean match(String input) {
		return (this.artist.indexOf(input) != -1) || (this.name.indexOf(input) != -1) || (this.album.indexOf(input) != -1);
	}
	
	/**
	 * @return the album
	 */
	public String getAlbum() {
		return album;
	}
	/**
	 * @param album the album to set
	 */
	public void setAlbum(String album) {
		this.album = album;
	}
	/**
	 * @return the artist
	 */
	public String getArtist() {
		return artist;
	}
	/**
	 * @param artist the artist to set
	 */
	public void setArtist(String artist) {
		this.artist = artist;
	}
	/**
	 * @return the name
	 */
	public String getName() {
		return name;
	}
	/**
	 * @param name the name to set
	 */
	public void setName(String name) {
		this.name = name;
	}
	/**
	 * @return the time
	 */
	public float getTime() {
		return time;
	}
	/**
	 * @param time the time to set
	 */
	public void setTime(float time) {
		this.time = time;
	}
	/**
	 * @return the track
	 */
	public int getTrack() {
		return track;
	}
	/**
	 * @param track the track to set
	 */
	public void setTrack(int track) {
		this.track = track;
	}

	/**
	 * Delete the file for this song
	 */
	public boolean delete() {
		return this.location.delete();
	}

}
