/**
 * 
 */
package uk.org.wuglug.gryle.ui.v;

import java.awt.Container;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JProgressBar;
import javax.swing.JTable;
import javax.swing.border.EtchedBorder;

import uk.org.wuglug.gryle.ui.m.PlayerController;
import uk.org.wuglug.gryle.ui.m.SongModel;
import uk.org.wuglug.gryle.ui.m.SongTableModel;

/**
 * @author Richard Warburton
 * main UI frontend
 */
public class FrontEnd extends JFrame implements ActionListener {

	private class feButton extends JButton {
		public feButton(String name,ActionListener act) {
			super(name);
			setOpaque(true);
			addActionListener(act);
		}
	}
	
	private JButton prev;
	private JButton next;
	private JButton pp;
	private JProgressBar playProgress;
	private JButton vol;
	
	private BottomPanel bottomPanel;
	
	private boolean playing;
	private String _PLAY = "play";
	private String _PAUSE = "pause";
	
	private static FrontEnd instance = new FrontEnd(); 

	/**
	 * @return the instance
	 */
	public static FrontEnd getInstance() {
		return instance;
	}

	private FrontEnd() {
		super("Gryle");
		this.playing = false;
		init();
	}

	private void init() {
		
		this.prev = new feButton("Prev",this);
		this.next = new feButton("Next",this);
		this.pp = new feButton(_PLAY,this);
		this.playProgress = new JProgressBar();
		this.vol = new feButton("Vol",this);
		this.bottomPanel = new BottomPanel();
		
		Box top = Box.createHorizontalBox();
		top.setBorder(new EtchedBorder(EtchedBorder.LOWERED));
		top.add(Box.createHorizontalStrut(5));
		top.add(this.prev);
		top.add(Box.createHorizontalStrut(5));
		top.add(this.pp);
		top.add(Box.createHorizontalStrut(5));
		top.add(this.next);
		top.add(Box.createHorizontalGlue());
		top.add(this.playProgress);
		top.add(Box.createHorizontalStrut(5));
		top.add(this.vol);
		top.add(Box.createHorizontalStrut(5));
		
		Container pane = getContentPane();
		pane.setLayout(new BoxLayout(pane,BoxLayout.Y_AXIS));
		pane.add(top);
		pane.add(Box.createVerticalStrut(5));
		pane.add(Box.createVerticalGlue());
		pane.add(bottomPanel);
		
		pack();
		setJMenuBar(new MainMenu());
		setVisible(true);
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}

	public void actionPerformed(ActionEvent e) {
		JButton button = (JButton) e.getSource();
		JTable songTable = this.bottomPanel.songTable;
		int row = songTable.getSelectedRow();
		if(button == this.prev) {
			row--;
			songTable.getSelectionModel().setSelectionInterval(row, row);
		} else if(button == this.next) {
			row++;
			songTable.getSelectionModel().setSelectionInterval(row, row);
		} else if(button == this.pp) {
			if(this.playing) {
				this.pp.setText(_PLAY);
				this.playing = false;
				PlayerController.getInstance().pause();
				
			} else {
				this.pp.setText(_PAUSE);
				this.playing = true;
				SongModel song = SongTableModel.getInst().getSong(row);
				PlayerController.getInstance().play(song.getLocation());
				
			}
		}/* else if(button == this.vol) {
			
		}*/
	}
	
}
